#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hOpenPGP
version:              2.10.1
visibility:           public
id:                   hOpenPGP-2.10.1-8SGe4M0SzImC5XftDKqM23
key:                  hOpenPGP-2.10.1-8SGe4M0SzImC5XftDKqM23
license:              MIT
copyright:            2012-2025  Clint Adams
maintainer:           Clint Adams <clint@debian.org>
author:               Clint Adams
homepage:             https://salsa.debian.org/clint/hOpenPGP
synopsis:             native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581), plus ECC (RFC6637)

category:             Codec, Data
abi:                  1f8594869628e7b334f19811b45de7a5
exposed:              True
exposed-modules:
    Codec.Encryption.OpenPGP.CFB Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.SignatureQualities
    Codec.Encryption.OpenPGP.Signatures Codec.Encryption.OpenPGP.Types
    Codec.Encryption.OpenPGP.Version Data.Conduit.OpenPGP.Compression
    Data.Conduit.OpenPGP.Decrypt Data.Conduit.OpenPGP.Filter
    Data.Conduit.OpenPGP.Keyring Data.Conduit.OpenPGP.Keyring.Instances
    Data.Conduit.OpenPGP.Verify

hidden-modules:
    Codec.Encryption.OpenPGP.Internal
    Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
    Codec.Encryption.OpenPGP.Internal.Crypton
    Codec.Encryption.OpenPGP.Internal.HOBlockCipher
    Codec.Encryption.OpenPGP.Types.Internal.Base
    Codec.Encryption.OpenPGP.Types.Internal.CryptonNewtypes
    Codec.Encryption.OpenPGP.Types.Internal.PKITypes
    Codec.Encryption.OpenPGP.Types.Internal.PacketClass
    Codec.Encryption.OpenPGP.Types.Internal.Pkt
    Codec.Encryption.OpenPGP.Types.Internal.PrettyUtils
    Codec.Encryption.OpenPGP.Types.Internal.TK
    Codec.Encryption.OpenPGP.BlockCipher
    Codec.Encryption.OpenPGP.SerializeForSigs Paths_hOpenPGP

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hOpenPGP-2.10.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hOpenPGP-2.10.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hOpenPGP-2.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hopenpgp
hs-libraries:         HShOpenPGP-2.10.1-8SGe4M0SzImC5XftDKqM23
depends:
    aeson-2.2.1.0-28ssJzlQESE12G8XLETNIx
    asn1-encoding-0.9.6-AzW87bpRIrYD7MMIGVjBrC
    attoparsec-0.14.4-AfQXKZj0AFm4MwPZbnzhvC base-4.18.2.1
    base16-bytestring-1.0.2.0-BqWVRU1IQoAP0y3rqebgF
    bifunctors-5.6.2-7OSBZDxKGDO4IlYhQVlyzt binary-0.8.9.1
    binary-conduit-1.3.1-8AM8kUm6a3f4GzcPRG1OEQ bytestring-0.11.5.3
    bz2-1.0.1.1-I0gV6OLiDj6EckS1nAZ2TS
    conduit-1.3.6.1-HUGtecX46l86IsV4eGce7U
    conduit-extra-1.3.8-95HgjxGSNFzI4mCY6bfwHh containers-0.6.7
    crypto-cipher-types-0.0.9-KR6SDml7aC01N7sg8RBO5C
    crypton-1.0.4-TJn5R4YGxkHJI4uBMudyO
    errors-2.3.0-7DruJFCzZyU1Xkrj1gUMYZ
    hashable-1.4.7.0-D2jhP8LVtgFIAnKx76ZNYr
    incremental-parser-0.5.1-8JHQs1O4ARh6xYaNfhSRe9
    ixset-typed-0.5.1.0-FpbJ2cYgBpj9AY9vxuzwex
    lens-5.3.4-4Gn3x9DAN5U4gsnCQbhlSx
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    monad-loops-0.4.3-LG7facWXNYz9W52syv7lz8
    nettle-0.3.1.1-DuwdlQIRX7hBXjJiv7OWDZ
    network-uri-2.6.4.2-Gnw0MjQFVGhFnasOtB45
    openpgp-asciiarmor-0.1.2-IdxS7Fe6EzzVxZBGhD5B6
    prettyprinter-1.7.1-6jg14vIwDos4Lqu7eMpEik
    resourcet-1.2.6-KQRlMPpwgywCMyAjouMcQ0
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    transformers-0.6.1.0 unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-ZzaTCzIdz8BWoPLHKXAc8
    zlib-0.7.0.0-4xfXei9KqrR3TNrmcaLViZ

haddock-interfaces:   /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html:         /usr/share/doc/haskell-hopenpgp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

